==> haskell-boxes-0.1.5-336-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-boxes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 boxes
version:              0.1.5
visibility:           public
id:                   boxes-0.1.5-94cqCjWQI8i6xEBELniH6X
key:                  boxes-0.1.5-94cqCjWQI8i6xEBELniH6X
license:              BSD-3-Clause
maintainer:           David Feuer <David.Feuer@gmail.com>
author:               Brent Yorgey
synopsis:             2D text pretty-printing library
description:
    A pretty-printing library for laying out text in
    two dimensions, using a simple box model.

category:             Text
abi:                  4c21e567abd48bceffe0f9cc415b4330
exposed:              True
exposed-modules:      Text.PrettyPrint.Boxes
import-dirs:          /usr/lib/ghc-9.6.6/site-local/boxes-0.1.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/boxes-0.1.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/boxes-0.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-boxes
hs-libraries:         HSboxes-0.1.5-94cqCjWQI8i6xEBELniH6X
depends:              base-4.18.2.1 split-0.2.5-KeBcC7WBTCHE2olxjxkqgK
haddock-interfaces:   /usr/share/doc/haskell-boxes/html/boxes.haddock
haddock-html:         /usr/share/doc/haskell-boxes/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-boxes-0.1.5-338-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-boxes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 boxes
version:              0.1.5
visibility:           public
id:                   boxes-0.1.5-EyIrDbdqYeNIiI1uBjUH8w
key:                  boxes-0.1.5-EyIrDbdqYeNIiI1uBjUH8w
license:              BSD-3-Clause
maintainer:           David Feuer <David.Feuer@gmail.com>
author:               Brent Yorgey
synopsis:             2D text pretty-printing library
description:
    A pretty-printing library for laying out text in
    two dimensions, using a simple box model.

category:             Text
abi:                  3f75a86bdedf96eec1557d9ade8a6cf6
exposed:              True
exposed-modules:      Text.PrettyPrint.Boxes
import-dirs:          /usr/lib/ghc-9.6.6/site-local/boxes-0.1.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/boxes-0.1.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/boxes-0.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-boxes
hs-libraries:         HSboxes-0.1.5-EyIrDbdqYeNIiI1uBjUH8w
depends:              base-4.18.2.1 split-0.2.5-LIo01L9HFTI75RwsLzYVkn
haddock-interfaces:   /usr/share/doc/haskell-boxes/html/boxes.haddock
haddock-html:         /usr/share/doc/haskell-boxes/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
